# SGNova

SGNova is a gravitational wave burst search pipeline written in the SGN framework.
Related libraries include:

- [`sgn`](https://docs.ligo.org/greg/sgn/): Base library for SGN
- [`sgn-event`](https://git.ligo.org/greg/sgn-event): TimeSeries utilities for SGN
- [`sgn-ts`](https://docs.ligo.org/greg/sgn-ts/): TimeSeries utilities for SGN
- [`sgn-ligo`](https://docs.ligo.org/greg/sgn-ligo/): LSC specific utilities for SGN

## Installation

To install SGNova, simply run:

```bash
pip install sgnova
```

More SGNova-specific documentation coming soon.

